.. _overview:

Overview
========

**PyAutoFit** requires Python 3.9 - 3.12 and support the Linux, MacOS and Windows operating systems.

**PyAutoFit** can be installed via the Python distribution `Anaconda <https://www.anaconda.com/>`_ or using
`Pypi <https://pypi.org/>`_ to ``pip install`` **PyAutoFit** into your Python distribution.

We recommend Anaconda as it manages the installation of many major libraries used by **PyAutoFit** (e.g. numpy, scipy,
matplotlib, etc.) making installation more straight forward.

The installation guide for both approaches can be found at:

- `Anaconda installation guide <https://pyautofit.readthedocs.io/en/latest/installation/conda.html>`_

- `PyPI installation guide <https://pyautofit.readthedocs.io/en/latest/installation/pip.html>`_

Users who wish to build **PyAutoFit** from source (e.g. via a ``git clone``) should follow
our `building from source installation guide <https://pyautofit.readthedocs.io/en/latest/installation/source.html>`_.

Known Issues
------------

There are currently no known issues with installing **PyAutoFit**.

Dependencies
------------

**PyAutoConf** https://github.com/rhayes777/PyAutoConf

**dynesty** https://github.com/joshspeagle/dynesty

**emcee** https://github.com/dfm/emcee

**PySwarms** https://github.com/ljvmiranda921/pyswarms

**astropy** https://www.astropy.org/

**corner.py** https://github.com/dfm/corner.py

**matplotlib** https://matplotlib.org/

**numpy** https://numpy.org/

**scipy** https://www.scipy.org/